==> prestashop_1.4.7.0.zip: prestashop/modules/gcheckout/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{gcheckout}prestashop>confirm_a40cab5994f36d4c48103a22ca082e8f'] = 'Ihr Warenkorb';
$_MODULE['<{gcheckout}prestashop>confirm_6c132b5e262594950586ae13a7d3aa94'] = 'Google Checkout';
$_MODULE['<{gcheckout}prestashop>confirm_f1d3b424cd68795ecaa552883759aceb'] = 'Bestellsumme';
$_MODULE['<{gcheckout}prestashop>confirm_3575814f89e55ba8061c55dd93214aae'] = 'Sie haben Google Checkout für Ihre Zahlung ausgewählt.';
$_MODULE['<{gcheckout}prestashop>confirm_c884ed19483d45970c5bf23a681e2dd2'] = 'Hier eine kurze Zusammenfassung Ihrer Bestellung:';
$_MODULE['<{gcheckout}prestashop>confirm_e2867a925cba382f1436d1834bb52a1c'] = 'Der Gesamtbetrag Ihrer Bestellung beträgt';
$_MODULE['<{gcheckout}prestashop>confirm_1f87346a16cf80c372065de3c54c86d9'] = '(Inkl. Mwst.)';
$_MODULE['<{gcheckout}prestashop>confirm_eecc59d9ca953545b6c5ac9bf11ded00'] = 'Wir akzeptieren die folgende Währung bei einer Zahlung mit Google Checkout:';
$_MODULE['<{gcheckout}prestashop>confirm_0881a11f7af33bc1b43e437391129d66'] = 'Bitte bestätigen Sie Ihre Bestellung durch Klicken auf \"BESTELLEN\"';
$_MODULE['<{gcheckout}prestashop>confirm_569fd05bdafa1712c4f6be5b153b8418'] = 'Andere Zahlungsmethoden';
$_MODULE['<{gcheckout}prestashop>confirm_46b9e3665f187c739c55983f757ccda0'] = 'BESTELLEN';
$_MODULE['<{gcheckout}prestashop>gcheckout_6c132b5e262594950586ae13a7d3aa94'] = 'Google Checkout';
$_MODULE['<{gcheckout}prestashop>gcheckout_3f3c0194c5adbe6953eb571f125af16d'] = 'Google Checkout-API-Implementierung';
$_MODULE['<{gcheckout}prestashop>gcheckout_4402acab1c8f90dcf4a31dc96833bd86'] = 'Keine Währung für dieses Modul eingestellt';
$_MODULE['<{gcheckout}prestashop>gcheckout_82b8bb0d807e6d2e43a068f954c3559f'] = 'Händler-ID scheint falsch zu sein';
$_MODULE['<{gcheckout}prestashop>gcheckout_9dd37c2106ceacbf0a40778b2109c386'] = 'Händler-Schlüssel scheint falsch zu sein';
$_MODULE['<{gcheckout}prestashop>gcheckout_f4f70727dc34561dfde1a3c529b6205c'] = 'Einstellungen';
$_MODULE['<{gcheckout}prestashop>gcheckout_cd1c5e22d4513c1912be45c9ce9ddbe2'] = 'API Version des Moduls ist 2.0';
$_MODULE['<{gcheckout}prestashop>gcheckout_a1ffd2dc2538ea3093532029514d42ac'] = 'Nutzen Sie zuerst die Sandbox, um das Modul zu testen, dann können Sie den Echtbetrieb-Modus benutzen, wenn alles in Ordnung ist. Vergessen Sie nicht, je nach Modus Händler-Schlüssel und -ID zu ändern!';
$_MODULE['<{gcheckout}prestashop>gcheckout_650be61892bf690026089544abbd9d26'] = 'Modus';
$_MODULE['<{gcheckout}prestashop>gcheckout_7f80fcc452c2f1ed2bb51b39d0864df1'] = 'Echtzeit';
$_MODULE['<{gcheckout}prestashop>gcheckout_2652eec977dcb2a5aea85f5bec235b05'] = 'Sandbox';
$_MODULE['<{gcheckout}prestashop>gcheckout_96fb435ae559f8a759f22f0823d57f7d'] = 'Bitte vergessen Sie nicht die Standard-Währung anzugeben.';
$_MODULE['<{gcheckout}prestashop>gcheckout_386c339d37e737a436499d423a77df0c'] = 'Währung';
$_MODULE['<{gcheckout}prestashop>gcheckout_76055653a95e0a559b734ec322d89632'] = 'Sie finden diese Schlüssel in Ihrem Google Checkout-Konto> Einstellungen> Integration. Sowohl Sandkasten als auch Echtzeit-Modus haben diese Tasten.';
$_MODULE['<{gcheckout}prestashop>gcheckout_229a7ec501323b94db7ff3157a7623c9'] = 'Händler-ID';
$_MODULE['<{gcheckout}prestashop>gcheckout_795acb9a0c89791314d3032fe65eeb92'] = 'Händler-Schlüssel';
$_MODULE['<{gcheckout}prestashop>gcheckout_a7ba8619e32091c343b340ec5b80e541'] = 'Wenn Sie dieses Feld ankreuzen, werden die Käufer in der Lage sein, die Versandkosten zu sehen, die Sie in Google Checkout auf der Kaufseite eingerichtet haben.';
$_MODULE['<{gcheckout}prestashop>gcheckout_de6fa0b14f259108c4b38e5be0374f46'] = 'Google Versandkosten benutzen';
$_MODULE['<{gcheckout}prestashop>gcheckout_74692aae1cff5dc9dfd44f8c4e0540ad'] = 'Sie können  die Server-zu-Server-Kommunikation protokollieren. Die Protokolldateien sind';
$_MODULE['<{gcheckout}prestashop>gcheckout_be5d5d37542d75f93a87094459f76678'] = 'und';
$_MODULE['<{gcheckout}prestashop>gcheckout_f2f19b2cbcb395e254ebb1d9bf7cccd4'] = 'Wenn Sie sie aktivieren, vergewissern Sie sich, dass Sie sie schützen, indem Sie eine .htaccess-Datei ins gleiche Verzeichnis speichern. Wenn Sie dies vergessen, werden sie von jedermann lesbar sein';
$_MODULE['<{gcheckout}prestashop>gcheckout_b2d37ae1cedf42ff874289b721860af2'] = 'Logs';
$_MODULE['<{gcheckout}prestashop>gcheckout_38fb7d24e0d60a048f540ecb18e13376'] = 'Speichern';
$_MODULE['<{gcheckout}prestashop>gcheckout_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Information';
$_MODULE['<{gcheckout}prestashop>gcheckout_968913ba2d4e25f3589d4c612ecbaa8d'] = 'Um Ihr Google Checkout-Modul zu verwenden, müssen Sie Ihr Google Checkout-Konto (Sandbox-Konto sowie Live-Konto)  konfigurieren. Melden Sie sich bei Google Checkout an, gehen Sie dann auf Einstellungen> Integration. Die API-Rückruf-URL lautet:';
$_MODULE['<{gcheckout}prestashop>gcheckout_dba727a9adc372723baef4533a7fc9da'] = 'Die Callback-Methode muss eingestellt werden auf';
$_MODULE['<{gcheckout}prestashop>gcheckout_0d46d15f70a7cfa670545b308c022840'] = 'Die Bestellungen müssen mit der gleichen Währung wie Ihr Verkäufer-Konto eingestellt werden. Warenkörbe in anderen Währungen werden umgerechnet, wenn der Kunde mit diesem Modul bezahlen möchte.';
$_MODULE['<{gcheckout}prestashop>gcheckout_8dd85f4218069de952672fe3180dacdb'] = 'Bezahlen Sie mit GoogleCheckout';
$_MODULE['<{gcheckout}prestashop>gcheckout_ba794350deb07c0c96fe73bd12239059'] = 'Verpackung';

?>

==> prestashop_1.5.0.1.zip: prestashop/modules/gcheckout/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{gcheckout}prestashop>confirm_a40cab5994f36d4c48103a22ca082e8f'] = 'Ihr Warenkorb';
$_MODULE['<{gcheckout}prestashop>confirm_6c132b5e262594950586ae13a7d3aa94'] = 'Google Checkout';
$_MODULE['<{gcheckout}prestashop>confirm_f1d3b424cd68795ecaa552883759aceb'] = 'Bestellsumme';
$_MODULE['<{gcheckout}prestashop>confirm_3575814f89e55ba8061c55dd93214aae'] = 'Sie haben Google Checkout für Ihre Zahlung ausgewählt.';
$_MODULE['<{gcheckout}prestashop>confirm_c884ed19483d45970c5bf23a681e2dd2'] = 'Hier eine kurze Zusammenfassung Ihrer Bestellung:';
$_MODULE['<{gcheckout}prestashop>confirm_e2867a925cba382f1436d1834bb52a1c'] = 'Der Gesamtbetrag Ihrer Bestellung beträgt';
$_MODULE['<{gcheckout}prestashop>confirm_1f87346a16cf80c372065de3c54c86d9'] = '(Inkl. Mwst.)';
$_MODULE['<{gcheckout}prestashop>confirm_eecc59d9ca953545b6c5ac9bf11ded00'] = 'Wir akzeptieren die folgende Währung bei einer Zahlung mit Google Checkout:';
$_MODULE['<{gcheckout}prestashop>confirm_0881a11f7af33bc1b43e437391129d66'] = 'Bitte bestätigen Sie Ihre Bestellung durch Klicken auf \"BESTELLEN\"';
$_MODULE['<{gcheckout}prestashop>confirm_569fd05bdafa1712c4f6be5b153b8418'] = 'Andere Zahlungsmethoden';
$_MODULE['<{gcheckout}prestashop>confirm_46b9e3665f187c739c55983f757ccda0'] = 'BESTELLEN';
$_MODULE['<{gcheckout}prestashop>gcheckout_6c132b5e262594950586ae13a7d3aa94'] = 'Google Checkout';
$_MODULE['<{gcheckout}prestashop>gcheckout_3f3c0194c5adbe6953eb571f125af16d'] = 'Google Checkout-API-Implementierung';
$_MODULE['<{gcheckout}prestashop>gcheckout_4402acab1c8f90dcf4a31dc96833bd86'] = 'Keine Währung für dieses Modul eingestellt';
$_MODULE['<{gcheckout}prestashop>gcheckout_82b8bb0d807e6d2e43a068f954c3559f'] = 'Händler-ID scheint falsch zu sein';
$_MODULE['<{gcheckout}prestashop>gcheckout_9dd37c2106ceacbf0a40778b2109c386'] = 'Händler-Schlüssel scheint falsch zu sein';
$_MODULE['<{gcheckout}prestashop>gcheckout_f4f70727dc34561dfde1a3c529b6205c'] = 'Einstellungen';
$_MODULE['<{gcheckout}prestashop>gcheckout_cd1c5e22d4513c1912be45c9ce9ddbe2'] = 'Die API-Version von diesem Modul beträgt 2,0';
$_MODULE['<{gcheckout}prestashop>gcheckout_a1ffd2dc2538ea3093532029514d42ac'] = 'Nutzen Sie zuerst die Sandbox, um das Modul zu testen, dann können Sie den Echtbetrieb-Modus benutzen, wenn alles in Ordnung ist. Vergessen Sie nicht, je nach Modus Händler-Schlüssel und -ID zu ändern!';
$_MODULE['<{gcheckout}prestashop>gcheckout_650be61892bf690026089544abbd9d26'] = 'Modus';
$_MODULE['<{gcheckout}prestashop>gcheckout_7f80fcc452c2f1ed2bb51b39d0864df1'] = 'Echtzeit';
$_MODULE['<{gcheckout}prestashop>gcheckout_2652eec977dcb2a5aea85f5bec235b05'] = 'Sandbox';
$_MODULE['<{gcheckout}prestashop>gcheckout_96fb435ae559f8a759f22f0823d57f7d'] = 'Vergessen Sie nicht, die Währung, in der Payment Tabs unter der Währung Abschnitt verwendeten angeben';
$_MODULE['<{gcheckout}prestashop>gcheckout_386c339d37e737a436499d423a77df0c'] = 'Währung';
$_MODULE['<{gcheckout}prestashop>gcheckout_76055653a95e0a559b734ec322d89632'] = 'Sie finden diese Schlüssel in Ihrem Google Checkout-Konto> Einstellungen> Integration. Sowohl Sandkasten als auch Echtzeit-Modus haben diese Tasten.';
$_MODULE['<{gcheckout}prestashop>gcheckout_229a7ec501323b94db7ff3157a7623c9'] = 'Händler-ID';
$_MODULE['<{gcheckout}prestashop>gcheckout_795acb9a0c89791314d3032fe65eeb92'] = 'Händler-Schlüssel';
$_MODULE['<{gcheckout}prestashop>gcheckout_a7ba8619e32091c343b340ec5b80e541'] = 'Wenn Sie dieses Feld ankreuzen, werden die Käufer in der Lage sein, die Versandkosten zu sehen, die Sie in Google Checkout auf der Kaufseite eingerichtet haben.';
$_MODULE['<{gcheckout}prestashop>gcheckout_de6fa0b14f259108c4b38e5be0374f46'] = 'Google Versandkosten benutzen';
$_MODULE['<{gcheckout}prestashop>gcheckout_74692aae1cff5dc9dfd44f8c4e0540ad'] = 'Sie können  die Server-zu-Server-Kommunikation protokollieren. Die Protokolldateien sind';
$_MODULE['<{gcheckout}prestashop>gcheckout_be5d5d37542d75f93a87094459f76678'] = 'und';
$_MODULE['<{gcheckout}prestashop>gcheckout_f2f19b2cbcb395e254ebb1d9bf7cccd4'] = 'Wenn Sie sie aktivieren, vergewissern Sie sich, dass Sie sie schützen, indem Sie eine .htaccess-Datei ins gleiche Verzeichnis speichern. Wenn Sie dies vergessen, werden sie von jedermann lesbar sein';
$_MODULE['<{gcheckout}prestashop>gcheckout_b2d37ae1cedf42ff874289b721860af2'] = 'Logs';
$_MODULE['<{gcheckout}prestashop>gcheckout_38fb7d24e0d60a048f540ecb18e13376'] = 'Speichern';
$_MODULE['<{gcheckout}prestashop>gcheckout_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Information';
$_MODULE['<{gcheckout}prestashop>gcheckout_968913ba2d4e25f3589d4c612ecbaa8d'] = 'Um Ihr Google Checkout-Modul zu verwenden, müssen Sie in Ihr Google Checkout-Konto (Sandbox-Konto sowie Live-Konto)  konfigurieren. Melden Sie sich bei Google Checkout an, gehen Sie dann auf Einstellungen> Integration. Die API-Rückruf-URL lautet:';
$_MODULE['<{gcheckout}prestashop>gcheckout_dba727a9adc372723baef4533a7fc9da'] = 'Die Callback-Methode muss eingestellt werden auf';
$_MODULE['<{gcheckout}prestashop>gcheckout_0d46d15f70a7cfa670545b308c022840'] = 'Die bestellungen müssen mit der gleichen Währung wie Ihr Verkäufer-Konto eingestelltwerden. Warenkörbe in anderen Währungen werden umgerechnet, wenn der Kunde mit diesem Modul bezahlen möchte.';
$_MODULE['<{gcheckout}prestashop>gcheckout_8dd85f4218069de952672fe3180dacdb'] = 'Bezahlen Sie mit GoogleCheckout';
$_MODULE['<{gcheckout}prestashop>gcheckout_ba794350deb07c0c96fe73bd12239059'] = 'Verpackung';
